var buster = require("buster");
var assert = buster.assert;
var loader = require("../lib/buster-module-loader");

buster.testCase("Loading module", {
    "from strings": {
        "should require module": function () {
            assert.equals(loader.load("buster"), require("buster"));
        },

        "should load object from module": function () {
            assert.equals(loader.load("buster#assert"), assert);
        },

        "should load nested object from module": function () {
            assert.equals(loader.load("buster#assert.equals"), assert.equals);
        },

        "should throw if loading non-existent object": function () {
            try {
                loader.load("buster#assert.zoomba");
                throw new Error("Didn't throw");
            } catch (e) {
                assert.equals(e.message, "buster#assert.zoomba is null or undefined");
            }
        },

        "should throw if requiring non-existent module": function () {
            try {
                loader.load("buster-zoomba");
                throw new Error("Didn't throw");
            } catch (e) {
                assert.equals(e.message, "Cannot find module 'buster-zoomba'");
            }
        }
    },

    "from object specification": {
        "should require module": function () {
            assert.equals(loader.load({ module: "buster" }), require("buster"));
        },

        "should load object from module": function () {
            assert.equals(loader.load({module: "buster", object: "assert"}), assert);
        },

        "should load nested object from module": function () {
            var object = loader.load({module: "buster", object: "assert.equals"});

            assert.equals(object, assert.equals);
        },

        "should throw if loading non-existent object": function () {
            try {
                loader.load({ module: "buster", object: "assert.zoomba" });
                throw new Error("Didn't throw");
            } catch (e) {
                assert.equals(e.message, "buster#assert.zoomba is null or undefined");
            }
        },

        "should throw if requiring non-existent module": function () {
            try {
                loader.load({ module: "buster-zoomba" });
                throw new Error("Didn't throw");
            } catch (e) {
                assert.equals(e.message, "Cannot find module 'buster-zoomba'");
            }
        }
    }
});
